@@ -1,10 +1,10 @@
 from datetime import datetime
-from typing import Optional, Tuple
+from typing import List, Optional, Tuple
 
 from pydantic import Field
 
 from .account import Account
-from .base import BaseModel
+from .base import BaseModel, MappedSequence
 from .job import Job
 from .workspace import WorkspaceRef
 
@@ -14,7 +14,6 @@ class Experiment(BaseModel):
     name: Optional[str] = None
     full_name: Optional[str] = None
     description: Optional[str] = None
-    owner: Account
     author: Account
     created: datetime
     workspace_ref: WorkspaceRef
@@ -33,7 +32,6 @@ class Task(BaseModel):
     id: str
     name: Optional[str] = None
     experiment_id: str
-    owner: Account
     author: Account
     created: datetime
     schedulable: bool = False
@@ -50,6 +48,16 @@ class Task(BaseModel):
         return sorted(self.jobs, key=lambda job: job.status.created)[-1]
 
 
+class Tasks(MappedSequence[Task]):
+    """
+    A sequence of :class:`Task` that also behaves like a mapping of task names to tasks,
+    i.e. you can use ``get()`` or ``__getitem__()`` with the name of the task.
+    """
+
+    def __init__(self, tasks: List[Task]):
+        super().__init__(tasks, {task.name: task for task in tasks if task.name is not None})
+
+
 class ExperimentsPage(BaseModel):
     data: Tuple[Experiment, ...]
     next_cursor: Optional[str] = None
